| Title: | Course Materials for Advanced Health Service Research Methods |
|---|---|
| Description: | A (one paragraph) description of what the package does and why it may be useful. |
| Authors: | Matthew Lavallee [aut, cre] |
| Maintainer: | Matthew Lavallee <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1 |
| Built: | 2026-06-05 10:23:02 UTC |
| Source: | https://github.com/MatthewLavallee/hsr716 |
create_project_folder() creates a .Rproj object in a new folder at the specified directory,
and then sets up a default directory structure.
create_project_folder(project_name, base_path = ".")create_project_folder(project_name, base_path = ".")
grab_homeworks() downloads a set of homework RMarkdown files from a specified URL.
grab_homeworks(variables)grab_homeworks(variables)